:: Build LinkChecker
:: Copyright (C) 2010-2011 Bastian Kleineidam
:: This program is free software; you can redistribute it and/or modify
:: it under the terms of the GNU General Public License as published by
:: the Free Software Foundation; either version 2 of the License, or
:: (at your option) any later version.
::
:: This program is distributed in the hope that it will be useful,
:: but WITHOUT ANY WARRANTY; without even the implied warranty of
:: MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
:: GNU General Public License for more details.
::
:: You should have received a copy of the GNU General Public License along
:: with this program; if not, write to the Free Software Foundation, Inc.,
:: 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
@echo off
:: Python version
set PYDIR=C:\Python27
set PYVER=2.7

:: END configuration, no need to change anything below

:: set platform architecture
for /f "usebackq tokens=*" %%a in (`%PYDIR%\python.exe -c "from distutils.util import get_platform;print get_platform()"`) do set PLATFORM="%%a"

:: detect compiler
if defined MSSdk (
    :: Microsoft SDK
    set COMPILER=
    set DISTUTILS_USE_SDK=1
) else if "%PLATFORM%" == "win32" (
    :: MinGW (only for 32bit platforms)
    set COMPILER="-c mingw32"
) else (
    echo "No Microsoft SDK or MinGW compiler detected."
    goto :finish
)

%PYDIR%\python.exe setup.py sdist --manifest-only
%PYDIR%\python.exe setup.py build %COMPILER%

:finish
